@@ -6,9 +6,12 @@ from .configuration import *
 from .party import *
 from .invoice import *
 from .account import *
+from .lang import *
 
 def register():
     Pool.register(
+        Lang,
+        Address,
         CashflowTemplate,
         Cashflow,
         Account,
@@ -17,7 +20,6 @@ def register():
         Move,
         Line,
         Invoice,
-        MoveForceDrawStart,
         InvoiceForceDrawStart,
         AuxiliaryBookStart,
         AuxiliaryPartyStart,
@@ -25,6 +27,7 @@ def register():
         PrintTrialBalanceStart,
         BankAccountNumber,
         OpenCashflowStart,
+        MoveFixNumberStart,
         module='account_plus', type_='model')
     Pool.register(
         AccountMoveSheet,
@@ -44,4 +47,5 @@ def register():
         PrintAuxiliaryParty,
         PrintTrialBalance,
         OpenCashflowStatement,
+        MoveFixNumber, 
         module='account_plus', type_='wizard')
