@@ -15,8 +15,10 @@ class Lang:
     def __setup__(cls):
         super(Lang, cls).__setup__()
 
-        lang_co, = cls.search([
+        lang_co = cls.search([
             ('code', '=', 'es_CO'),
             ])
-
-        cls.write([lang_co], {'thousands_sep': '.'})
+        if lang_co:
+            lang_co = lang_co[0]
+            if lang_co.thousands_sep == None:
+                cls.write([lang_co], {'thousands_sep': '.'})
